# 👀 caniusethat

[![Documentation Status](https://readthedocs.org/projects/caniusethat/badge/?version=latest)](https://caniusethat.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/caniusethat)](https://pypi.org/project/caniusethat/)
[![License: MIT](https://img.shields.io/badge/license-MIT-brightgreen)](https://github.com/matpompili/caniusethat/blob/main/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Tests](https://github.com/matpompili/caniusethat/actions/workflows/python-package.yml/badge.svg)](https://github.com/matpompili/caniusethat/actions/workflows/python-package.yml)
[![Codacy Code Quality](https://app.codacy.com/project/badge/Grade/524f9decd5824df29734e1c9573a4af5)](https://www.codacy.com/gh/matpompili/caniusethat/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=matpompili/caniusethat&amp;utm_campaign=Badge_Grade)
[![Codacy Coverage](https://app.codacy.com/project/badge/Coverage/524f9decd5824df29734e1c9573a4af5)](https://www.codacy.com/gh/matpompili/caniusethat/dashboard?utm_source=github.com&utm_medium=referral&utm_content=matpompili/caniusethat&utm_campaign=Badge_Coverage)
Can I Use That is a wrapper around PyZMQ that enables easy RPC (remote procedure call) functionality

## Get started

CanIUseThat can be installed via `pip`:

```bash
pip install caniusethat
```